@@ -23,6 +23,7 @@ DEALINGS IN THE SOFTWARE.
 
 import os
 import socketio
+import aioftp
 
 from typing import Any, Dict
 
@@ -45,6 +46,7 @@ class Sessions:
     )
     stripe: Any
     smtp: SMTP
+    ftp: aioftp.Client
 
 
 class Config:
@@ -53,6 +55,10 @@ class Config:
         current_dir,
         "maps"
     )
+    plugin_dir = os.path.join(
+        current_dir,
+        "plugins"
+    )
     steam_openid_url = "https://steamcommunity.com/openid/login"
     upload_type: Any
     url: str
